/*
 * Copyright 2020-2022 Neural Layer
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.roboquant.iex

import org.junit.jupiter.api.Test
import org.roboquant.common.Asset
import org.roboquant.common.Timeframe
import org.roboquant.common.minutes
import org.roboquant.feeds.PriceAction
import org.roboquant.feeds.filter
import kotlin.test.assertTrue

internal class IEXHistoricFeedTestIT {

    @Test
    fun test() {
        System.getProperty("TEST_IEX") ?: return
        val feed = IEXHistoricFeed()
        val asset = Asset("AAPL")
        feed.retrieveIntraday(listOf(asset))
        assertTrue(asset in feed.assets)

        val actions = feed.filter<PriceAction>(Timeframe.next(5.minutes))
        assertTrue(actions.isNotEmpty())
    }

    @Test
    fun testPriceBar() {
        System.getProperty("TEST_IEX") ?: return
        val feed = IEXHistoricFeed()
        val asset = Asset("AAPL")
        feed.retrieve(listOf(asset))
        Thread.sleep(2000)
        val actions = feed.filter<PriceAction>(Timeframe.next(5.minutes))
        assertTrue(actions.isNotEmpty())
    }

    @Test
    fun testIntraday() {
        System.getProperty("TEST_IEX") ?: return
        val feed = IEXHistoricFeed()
        feed.retrieveIntraday("AAPL")
        val actions = feed.filter<PriceAction>(Timeframe.next(5.minutes))
        assertTrue(actions.isNotEmpty())
    }

}